@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,6 +27,7 @@ through the code to commit the whitespace formatting.
 """
 
 from yapf.yapflib import format_token
+from yapf.yapflib import object_state
 from yapf.yapflib import split_penalty
 from yapf.yapflib import style
 from yapf.yapflib import unwrapped_line
@@ -42,14 +43,13 @@ class FormatDecisionState(object):
     column: The number of used columns in the current line.
     next_token: The next token to be formatted.
     paren_level: The level of nesting inside (), [], and {}.
-    start_of_line_level: The paren_level at the start of this line.
     lowest_level_on_line: The lowest paren_level on the current line.
     newline: Indicates if a newline is added along the edge to this format
       decision state node.
     previous: The previous format decision state in the decision tree.
     stack: A stack (of _ParenState) keeping track of properties applying to
       parenthesis levels.
-    comp_stack: A stack (of _ComprehensionState) keeping track of properties
+    comp_stack: A stack (of ComprehensionState) keeping track of properties
       applying to comprehensions.
     ignore_stack_for_comparison: Ignore the stack of _ParenState for state
       comparison.
@@ -69,7 +69,6 @@ class FormatDecisionState(object):
     self.column = first_indent
     self.line = line
     self.paren_level = 0
-    self.start_of_line_level = 0
     self.lowest_level_on_line = 0
     self.ignore_stack_for_comparison = False
     self.stack = [_ParenState(first_indent, first_indent)]
@@ -86,7 +85,7 @@ class FormatDecisionState(object):
     new.column = self.column
     new.line = self.line
     new.paren_level = self.paren_level
-    new.start_of_line_level = self.start_of_line_level
+    new.line.depth = self.line.depth
     new.lowest_level_on_line = self.lowest_level_on_line
     new.ignore_stack_for_comparison = self.ignore_stack_for_comparison
     new.first_indent = self.first_indent
@@ -103,7 +102,7 @@ class FormatDecisionState(object):
     return (self.next_token == other.next_token and
             self.column == other.column and
             self.paren_level == other.paren_level and
-            self.start_of_line_level == other.start_of_line_level and
+            self.line.depth == other.line.depth and
             self.lowest_level_on_line == other.lowest_level_on_line and
             (self.ignore_stack_for_comparison or
              other.ignore_stack_for_comparison or
@@ -114,7 +113,7 @@ class FormatDecisionState(object):
 
   def __hash__(self):
     return hash((self.next_token, self.column, self.paren_level,
-                 self.start_of_line_level, self.lowest_level_on_line))
+                 self.line.depth, self.lowest_level_on_line))
 
   def __repr__(self):
     return ('column::%d, next_token::%s, paren_level::%d, stack::[\n\t%s' %
@@ -162,6 +161,9 @@ class FormatDecisionState(object):
         if not style.Get('ALLOW_SPLIT_BEFORE_DICT_VALUE'):
           return False
 
+    if previous and previous.value == '.' and current.value == '.':
+      return False
+
     return current.can_break_before
 
   def MustSplit(self):
@@ -178,7 +180,11 @@ class FormatDecisionState(object):
     if not previous:
       return False
 
-    if self.stack[-1].split_before_closing_bracket and current.value in '}]':
+    if style.Get('SPLIT_ALL_COMMA_SEPARATED_VALUES') and previous.value == ',':
+      return True
+
+    if (self.stack[-1].split_before_closing_bracket and
+        current.value in '}]' and style.Get('SPLIT_BEFORE_CLOSING_BRACKET')):
       # Split before the closing bracket if we can.
       return current.node_split_penalty != split_penalty.UNBREAKABLE
 
@@ -294,14 +300,13 @@ class FormatDecisionState(object):
           # This is a dictionary that's an argument to a function.
           if (self._FitsOnLine(previous, previous.matching_bracket) and
               previous.matching_bracket.next_token and
-              not previous.matching_bracket.next_token.ClosesScope() and
               (not opening.matching_bracket.next_token or
-               opening.matching_bracket.next_token.value != '.')):
+               opening.matching_bracket.next_token.value != '.') and
+              _ScopeHasNoCommas(previous)):
             # Don't split before the key if:
             #   - The dictionary fits on a line, and
-            #   - The dictionary brackets don't have a closing scope after
-            #     them, and
-            #   - The function call isn't part of a builder-style call.
+            #   - The function call isn't part of a builder-style call and
+            #   - The dictionary has one entry and no trailing comma
             return False
       return True
 
@@ -437,32 +442,26 @@ class FormatDecisionState(object):
           if self._FitsOnLine(previous, previous.matching_bracket):
             return False
         elif not self._FitsOnLine(previous, previous.matching_bracket):
+          if len(previous.container_elements) == 1:
+            return False
+
+          elements = previous.container_elements + [previous.matching_bracket]
+          i = 1
+          while i < len(elements):
+            if (not elements[i - 1].OpensScope() and
+                not self._FitsOnLine(elements[i - 1], elements[i])):
+              return True
+            i += 1
+
           if (self.column_limit - self.column) / float(self.column_limit) < 0.3:
             # Try not to squish all of the arguments off to the right.
-            return current.next_token != previous.matching_bracket
+            return True
       else:
         # Split after the opening of a container if it doesn't fit on the
         # current line.
         if not self._FitsOnLine(previous, previous.matching_bracket):
           return True
 
-    ###########################################################################
-    # List Comprehension Splitting
-    if (format_token.Subtype.COMP_FOR in current.subtypes and
-        format_token.Subtype.COMP_FOR not in previous.subtypes):
-      # Split at the beginning of a list comprehension.
-      length = _GetLengthOfSubtype(current, format_token.Subtype.COMP_FOR,
-                                   format_token.Subtype.COMP_IF)
-      if length + self.column > self.column_limit:
-        return True
-
-    if (format_token.Subtype.COMP_IF in current.subtypes and
-        format_token.Subtype.COMP_IF not in previous.subtypes):
-      # Split at the beginning of an if expression.
-      length = _GetLengthOfSubtype(current, format_token.Subtype.COMP_IF)
-      if length + self.column > self.column_limit:
-        return True
-
     ###########################################################################
     # Original Formatting Splitting
     # These checks rely upon the original formatting. This is in order to
@@ -560,11 +559,15 @@ class FormatDecisionState(object):
     self.column = self._GetNewlineColumn()
 
     if not dry_run:
-      current.AddWhitespacePrefix(newlines_before=1, spaces=self.column)
+      indent_level = self.line.depth
+      spaces = self.column
+      if spaces:
+        spaces -= indent_level * style.Get('INDENT_WIDTH')
+      current.AddWhitespacePrefix(
+          newlines_before=1, spaces=spaces, indent_level=indent_level)
 
     if not current.is_comment:
       self.stack[-1].last_space = self.column
-    self.start_of_line_level = self.paren_level
     self.lowest_level_on_line = self.paren_level
 
     if (previous.OpensScope() or
@@ -604,116 +607,6 @@ class FormatDecisionState(object):
 
     return penalty + 10
 
-  def _GetNewlineColumn(self):
-    """Return the new column on the newline."""
-    current = self.next_token
-    previous = current.previous_token
-    top_of_stack = self.stack[-1]
-
-    if current.spaces_required_before > 2 or self.line.disable:
-      return current.spaces_required_before
-
-    if current.OpensScope():
-      return top_of_stack.indent if self.paren_level else self.first_indent
-
-    if current.ClosesScope():
-      if (previous.OpensScope() or
-          (previous.is_comment and previous.previous_token is not None and
-           previous.previous_token.OpensScope())):
-        return max(0,
-                   top_of_stack.indent - style.Get('CONTINUATION_INDENT_WIDTH'))
-      return top_of_stack.closing_scope_indent
-
-    if (previous and previous.is_string and current.is_string and
-        format_token.Subtype.DICTIONARY_VALUE in current.subtypes):
-      return previous.column
-
-    if style.Get('INDENT_DICTIONARY_VALUE'):
-      if previous and (previous.value == ':' or previous.is_pseudo_paren):
-        if format_token.Subtype.DICTIONARY_VALUE in current.subtypes:
-          return top_of_stack.indent
-
-    if (_IsCompoundStatement(self.line.first) and
-        (not style.Get('DEDENT_CLOSING_BRACKETS') or
-         style.Get('SPLIT_BEFORE_FIRST_ARGUMENT'))):
-      token_indent = (
-          len(self.line.first.whitespace_prefix.split('\n')[-1]) +
-          style.Get('INDENT_WIDTH'))
-      if token_indent == top_of_stack.indent:
-        return top_of_stack.indent + style.Get('CONTINUATION_INDENT_WIDTH')
-
-    return top_of_stack.indent
-
-  def _CalculateComprehensionState(self, newline):
-    """Makes required changes to comprehension state.
-
-    Args:
-      newline: Whether the current token is to be added on a newline.
-
-    Returns:
-      The penalty for the token-newline combination given the current
-      comprehension state.
-    """
-    current = self.next_token
-    previous = current.previous_token
-    top_of_stack = self.comp_stack[-1] if self.comp_stack else None
-    penalty = 0
-
-    if top_of_stack is not None:
-      # Check if the token terminates the current comprehension.
-      if current == top_of_stack.closing_bracket:
-        last = self.comp_stack.pop()
-        # Lightly penalize comprehensions that are split across multiple lines.
-        if last.has_interior_split:
-          penalty += style.Get('SPLIT_PENALTY_COMPREHENSION')
-
-        return penalty
-
-      if newline:
-        top_of_stack.has_interior_split = True
-
-    if (format_token.Subtype.COMP_EXPR in current.subtypes and
-        format_token.Subtype.COMP_EXPR not in previous.subtypes):
-      self.comp_stack.append(_ComprehensionState(current))
-
-      return penalty
-
-    if (current.value == 'for' and
-        format_token.Subtype.COMP_FOR in current.subtypes):
-      if top_of_stack.for_token is not None:
-        # Treat nested comprehensions like normal comp_if expressions.
-        # Example:
-        #     my_comp = [
-        #         a.qux + b.qux
-        #         for a in foo
-        #   -->   for b in bar   <--
-        #         if a.zut + b.zut
-        #     ]
-        if (style.Get('SPLIT_COMPLEX_COMPREHENSION') and
-            top_of_stack.has_split_at_for != newline and
-            (top_of_stack.has_split_at_for or
-             not top_of_stack.HasTrivialExpr())):
-          penalty += split_penalty.UNBREAKABLE
-      else:
-        top_of_stack.for_token = current
-        top_of_stack.has_split_at_for = newline
-
-        # Try to keep trivial expressions on the same line as the comp_for.
-        if (style.Get('SPLIT_COMPLEX_COMPREHENSION') and newline and
-            top_of_stack.HasTrivialExpr()):
-          penalty += split_penalty.CONNECTED
-
-    if (format_token.Subtype.COMP_IF in current.subtypes and
-        format_token.Subtype.COMP_IF not in previous.subtypes):
-      # Penalize breaking at comp_if when it doesn't match the newline structure
-      # in the rest of the comprehension.
-      if (style.Get('SPLIT_COMPLEX_COMPREHENSION') and
-          top_of_stack.has_split_at_for != newline and
-          (top_of_stack.has_split_at_for or not top_of_stack.HasTrivialExpr())):
-        penalty += split_penalty.UNBREAKABLE
-
-    return penalty
-
   def MoveStateToNextToken(self):
     """Calculate format decision state information and move onto the next token.
 
@@ -759,7 +652,8 @@ class FormatDecisionState(object):
 
     # Calculate the penalty for overflowing the column limit.
     penalty = 0
-    if not current.is_pylint_comment and self.column > self.column_limit:
+    if (not current.is_pylint_comment and not current.is_pytype_comment and
+        self.column > self.column_limit):
       excess_characters = self.column - self.column_limit
       penalty += style.Get('SPLIT_PENALTY_EXCESS_CHARACTER') * excess_characters
 
@@ -770,6 +664,115 @@ class FormatDecisionState(object):
 
     return penalty
 
+  def _CalculateComprehensionState(self, newline):
+    """Makes required changes to comprehension state.
+
+    Args:
+      newline: Whether the current token is to be added on a newline.
+
+    Returns:
+      The penalty for the token-newline combination given the current
+      comprehension state.
+    """
+    current = self.next_token
+    previous = current.previous_token
+    top_of_stack = self.comp_stack[-1] if self.comp_stack else None
+    penalty = 0
+
+    if top_of_stack is not None:
+      # Check if the token terminates the current comprehension.
+      if current == top_of_stack.closing_bracket:
+        last = self.comp_stack.pop()
+        # Lightly penalize comprehensions that are split across multiple lines.
+        if last.has_interior_split:
+          penalty += style.Get('SPLIT_PENALTY_COMPREHENSION')
+
+        return penalty
+
+      if newline:
+        top_of_stack.has_interior_split = True
+
+    if (format_token.Subtype.COMP_EXPR in current.subtypes and
+        format_token.Subtype.COMP_EXPR not in previous.subtypes):
+      self.comp_stack.append(object_state.ComprehensionState(current))
+      return penalty
+
+    if (current.value == 'for' and
+        format_token.Subtype.COMP_FOR in current.subtypes):
+      if top_of_stack.for_token is not None:
+        # Treat nested comprehensions like normal comp_if expressions.
+        # Example:
+        #     my_comp = [
+        #         a.qux + b.qux
+        #         for a in foo
+        #   -->   for b in bar   <--
+        #         if a.zut + b.zut
+        #     ]
+        if (style.Get('SPLIT_COMPLEX_COMPREHENSION') and
+            top_of_stack.has_split_at_for != newline and
+            (top_of_stack.has_split_at_for or
+             not top_of_stack.HasTrivialExpr())):
+          penalty += split_penalty.UNBREAKABLE
+      else:
+        top_of_stack.for_token = current
+        top_of_stack.has_split_at_for = newline
+
+        # Try to keep trivial expressions on the same line as the comp_for.
+        if (style.Get('SPLIT_COMPLEX_COMPREHENSION') and newline and
+            top_of_stack.HasTrivialExpr()):
+          penalty += split_penalty.CONNECTED
+
+    if (format_token.Subtype.COMP_IF in current.subtypes and
+        format_token.Subtype.COMP_IF not in previous.subtypes):
+      # Penalize breaking at comp_if when it doesn't match the newline structure
+      # in the rest of the comprehension.
+      if (style.Get('SPLIT_COMPLEX_COMPREHENSION') and
+          top_of_stack.has_split_at_for != newline and
+          (top_of_stack.has_split_at_for or not top_of_stack.HasTrivialExpr())):
+        penalty += split_penalty.UNBREAKABLE
+
+    return penalty
+
+  def _GetNewlineColumn(self):
+    """Return the new column on the newline."""
+    current = self.next_token
+    previous = current.previous_token
+    top_of_stack = self.stack[-1]
+
+    if current.spaces_required_before > 2 or self.line.disable:
+      return current.spaces_required_before
+
+    if current.OpensScope():
+      return top_of_stack.indent if self.paren_level else self.first_indent
+
+    if current.ClosesScope():
+      if (previous.OpensScope() or
+          (previous.is_comment and previous.previous_token is not None and
+           previous.previous_token.OpensScope())):
+        return max(0,
+                   top_of_stack.indent - style.Get('CONTINUATION_INDENT_WIDTH'))
+      return top_of_stack.closing_scope_indent
+
+    if (previous and previous.is_string and current.is_string and
+        format_token.Subtype.DICTIONARY_VALUE in current.subtypes):
+      return previous.column
+
+    if style.Get('INDENT_DICTIONARY_VALUE'):
+      if previous and (previous.value == ':' or previous.is_pseudo_paren):
+        if format_token.Subtype.DICTIONARY_VALUE in current.subtypes:
+          return top_of_stack.indent
+
+    if (_IsCompoundStatement(self.line.first) and
+        (not style.Get('DEDENT_CLOSING_BRACKETS') or
+         style.Get('SPLIT_BEFORE_FIRST_ARGUMENT'))):
+      token_indent = (
+          len(self.line.first.whitespace_prefix.split('\n')[-1]) +
+          style.Get('INDENT_WIDTH'))
+      if token_indent == top_of_stack.indent:
+        return top_of_stack.indent + style.Get('CONTINUATION_INDENT_WIDTH')
+
+    return top_of_stack.indent
+
   def _FitsOnLine(self, start, end):
     """Determines if line between start and end can fit on the current line."""
     length = end.total_length - start.total_length
@@ -813,7 +816,7 @@ class FormatDecisionState(object):
              format_token.Subtype.DICTIONARY_VALUE in current.subtypes) or
             ImplicitStringConcatenation(current)):
           # A dictionary entry that cannot fit on a single line shouldn't matter
-          # to this calcuation. If it can't fit on a single line, then the
+          # to this calculation. If it can't fit on a single line, then the
           # opening should be on the same line as the key and the rest on
           # newlines after it. But the other entries should be on single lines
           # if possible.
@@ -946,6 +949,20 @@ def _IsSingleElementTuple(token):
   return num_commas == 1
 
 
+def _ScopeHasNoCommas(token):
+  """Check if the scope has no commas."""
+  close = token.matching_bracket
+  token = token.next_token
+  while token != close:
+    if token.value == ',':
+      return False
+    if token.OpensScope():
+      token = token.matching_bracket
+    else:
+      token = token.next_token
+  return True
+
+
 class _ParenState(object):
   """Maintains the state of the bracket enclosures.
 
@@ -992,60 +1009,3 @@ class _ParenState(object):
   def __hash__(self, *args, **kwargs):
     return hash((self.indent, self.last_space, self.closing_scope_indent,
                  self.split_before_closing_bracket, self.num_line_splits))
-
-
-class _ComprehensionState(object):
-  """Maintains the state of list comprehension line-break decisions.
-
-  A stack of _ComprehensionState objects are kept to ensure that list
-  comprehensions are wrapped with well-defined rules.
-
-  Attributes:
-    expr_token: The first token in the comprehension.
-    for_token: The first 'for' token of the comprehension.
-    has_split_at_for: Whether there is a newline immediately before the
-        for_token.
-    has_interior_split: Whether there is a newline within the comprehension.
-        That is, a split somewhere after expr_token or before closing_bracket.
-  """
-
-  def __init__(self, expr_token):
-    self.expr_token = expr_token
-    self.for_token = None
-    self.has_split_at_for = False
-    self.has_interior_split = False
-
-  def HasTrivialExpr(self):
-    """Returns whether the comp_expr is "trivial" i.e. is a single token."""
-    return self.expr_token.next_token.value == 'for'
-
-  @property
-  def opening_bracket(self):
-    return self.expr_token.previous_token
-
-  @property
-  def closing_bracket(self):
-    return self.opening_bracket.matching_bracket
-
-  def Clone(self):
-    clone = _ComprehensionState(self.expr_token)
-    clone.for_token = self.for_token
-    clone.has_split_at_for = self.has_split_at_for
-    clone.has_interior_split = self.has_interior_split
-    return clone
-
-  def __repr__(self):
-    return ('[opening_bracket::%s, for_token::%s, has_split_at_for::%s,'
-            ' has_interior_split::%s, has_trivial_expr::%s]' %
-            (self.opening_bracket, self.for_token, self.has_split_at_for,
-             self.has_interior_split, self.HasTrivialExpr()))
-
-  def __eq__(self, other):
-    return hash(self) == hash(other)
-
-  def __ne__(self, other):
-    return not self == other
-
-  def __hash__(self, *args, **kwargs):
-    return hash((self.expr_token, self.for_token, self.has_split_at_for,
-                 self.has_interior_split))
