@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -80,28 +80,31 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
 
     if not comp_for and dict_maker:
       last_was_colon = False
+      unpacking = False
       for child in node.children:
-        if dict_maker:
-          if pytree_utils.NodeName(child) == 'DOUBLESTAR':
+        if pytree_utils.NodeName(child) == 'DOUBLESTAR':
+          _AppendFirstLeafTokenSubtype(child,
+                                       format_token.Subtype.KWARGS_STAR_STAR)
+        if last_was_colon:
+          if style.Get('INDENT_DICTIONARY_VALUE'):
+            _InsertPseudoParentheses(child)
+          else:
             _AppendFirstLeafTokenSubtype(child,
-                                         format_token.Subtype.KWARGS_STAR_STAR)
-          if last_was_colon:
-            if style.Get('INDENT_DICTIONARY_VALUE'):
-              _InsertPseudoParentheses(child)
-            else:
-              _AppendFirstLeafTokenSubtype(
-                  child, format_token.Subtype.DICTIONARY_VALUE)
-          elif (
-              child is not None and
-              (isinstance(child, pytree.Node) or
-               (not child.value.startswith('#') and child.value not in '{:,'))):
-            # Mark the first leaf of a key entry as a DICTIONARY_KEY. We
-            # normally want to split before them if the dictionary cannot exist
-            # on a single line.
+                                         format_token.Subtype.DICTIONARY_VALUE)
+        elif (isinstance(child, pytree.Node) or
+              (not child.value.startswith('#') and child.value not in '{:,')):
+          # Mark the first leaf of a key entry as a DICTIONARY_KEY. We
+          # normally want to split before them if the dictionary cannot exist
+          # on a single line.
+          if not unpacking or pytree_utils.FirstLeafNode(child).value == '**':
             _AppendFirstLeafTokenSubtype(child,
                                          format_token.Subtype.DICTIONARY_KEY)
-            _AppendSubtypeRec(child, format_token.Subtype.DICTIONARY_KEY_PART)
+          _AppendSubtypeRec(child, format_token.Subtype.DICTIONARY_KEY_PART)
         last_was_colon = pytree_utils.NodeName(child) == 'COLON'
+        if pytree_utils.NodeName(child) == 'DOUBLESTAR':
+          unpacking = True
+        elif last_was_colon:
+          unpacking = False
 
   def Visit_expr_stmt(self, node):  # pylint: disable=invalid-name
     # expr_stmt ::= testlist_star_expr (augassign (yield_expr|testlist)
@@ -192,7 +195,7 @@ class _SubtypeAssigner(pytree_visitor.PyTreeVisitor):
     for child in node.children:
       self.Visit(child)
       if (isinstance(child, pytree.Leaf) and
-          child.value in {'*', '/', '%', '//'}):
+          child.value in {'*', '/', '%', '//', '@'}):
         _AppendTokenSubtype(child, format_token.Subtype.BINARY_OPERATOR)
 
   def Visit_factor(self, node):  # pylint: disable=invalid-name
@@ -381,8 +384,8 @@ def _InsertPseudoParentheses(node):
       comment_node = node.children[-1].clone()
       node.children[-1].remove()
 
-  first = _GetFirstLeafNode(node)
-  last = _GetLastLeafNode(node)
+  first = pytree_utils.FirstLeafNode(node)
+  last = pytree_utils.LastLeafNode(node)
 
   if first == last and first.type == token.COMMENT:
     # A comment was inserted before the value, which is a pytree.Leaf.
@@ -393,8 +396,8 @@ def _InsertPseudoParentheses(node):
     node = new_node
     last.remove()
 
-    first = _GetFirstLeafNode(node)
-    last = _GetLastLeafNode(node)
+    first = pytree_utils.FirstLeafNode(node)
+    last = pytree_utils.LastLeafNode(node)
 
   lparen = pytree.Leaf(
       token.LPAR, u'(', context=('', (first.get_lineno(), first.column - 1)))
@@ -423,15 +426,3 @@ def _InsertPseudoParentheses(node):
     new_node = pytree.Node(syms.atom, [lparen, clone, rparen])
     node.replace(new_node)
     _AppendFirstLeafTokenSubtype(clone, format_token.Subtype.DICTIONARY_VALUE)
-
-
-def _GetFirstLeafNode(node):
-  if isinstance(node, pytree.Leaf):
-    return node
-  return _GetFirstLeafNode(node.children[0])
-
-
-def _GetLastLeafNode(node):
-  if isinstance(node, pytree.Leaf):
-    return node
-  return _GetLastLeafNode(node.children[-1])
