@@ -1,4 +1,4 @@
-# Copyright 2015-2017 Google Inc. All Rights Reserved.
+# Copyright 2015 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -255,7 +255,8 @@ def _SpaceRequiredBetween(left, right):
   if lval == '.' and rval == 'import':
     # Space after the '.' in an import statement.
     return True
-  if lval == '=' and rval == '.':
+  if (lval == '=' and rval == '.' and
+      format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN not in left.subtypes):
     # Space between equal and '.' as in "X = ...".
     return True
   if ((right.is_keyword or right.is_name) and
@@ -271,8 +272,9 @@ def _SpaceRequiredBetween(left, right):
     # A typed argument should have a space after the colon.
     return True
   if left.is_string:
-    if (rval == '=' and format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN_ARG_LIST in
-        right.subtypes):
+    if (rval == '=' and
+        format_token.Subtype.DEFAULT_OR_NAMED_ASSIGN_ARG_LIST in right.subtypes
+       ):
       # If there is a type hint, then we don't want to add a space between the
       # equal sign and the hint.
       return False
@@ -281,7 +283,7 @@ def _SpaceRequiredBetween(left, right):
       # or dot should have a space after it.
       return True
   if left.is_binary_op and lval != '**' and _IsUnaryOperator(right):
-    # Space between the binary opertor and the unary operator.
+    # Space between the binary operator and the unary operator.
     return True
   if left.is_keyword and _IsUnaryOperator(right):
     # Handle things like "not -3 < x".
@@ -315,12 +317,18 @@ def _SpaceRequiredBetween(left, right):
   if lval == '@' and format_token.Subtype.DECORATOR in left.subtypes:
     # Decorators shouldn't be separated from the 'at' sign.
     return False
+  if left.is_keyword and rval == '.':
+    # Add space between keywords and dots.
+    return lval != 'None' and lval != 'print'
+  if lval == '.' and right.is_keyword:
+    # Add space between keywords and dots.
+    return rval != 'None' and rval != 'print'
   if lval == '.' or rval == '.':
     # Don't place spaces between dots.
     return False
   if ((lval == '(' and rval == ')') or (lval == '[' and rval == ']') or
       (lval == '{' and rval == '}')):
-    # Empty objects shouldn't be separted by spaces.
+    # Empty objects shouldn't be separated by spaces.
     return False
   if (lval in pytree_utils.OPENING_BRACKETS and
       rval in pytree_utils.OPENING_BRACKETS):
@@ -455,7 +463,7 @@ def IsSurroundedByBrackets(tok):
 
 _LOGICAL_OPERATORS = frozenset({'and', 'or'})
 _BITWISE_OPERATORS = frozenset({'&', '|', '^'})
-_TERM_OPERATORS = frozenset({'*', '/', '%', '//'})
+_TERM_OPERATORS = frozenset({'*', '/', '%', '//', '@'})
 
 
 def _SplitPenalty(prev_token, cur_token):
